[![lerna](https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg)](https://lerna.js.org/)

[![pipeline status](https://gitlab.gk.gk-software.com/omnicommerce/app-enablement-api/badges/develop/pipeline.svg)](https://gitlab.gk.gk-software.com/omnicommerce/app-enablement-api/-/commits/develop)

[License](LICENSE.md)

[See an example of usage in client app](https://gitlab.gk.gk-software.com/omnicommerce/app-debug)

[To the overview page](../../README.md)

# AppEnablement Client API
App Enablement provides access to the functionality of the host application (MobilePOS, OmniPOS, ...). The functionality is provided for a JavaScript application running in the host application.

## Development
1. ``npm install``
2. ``gulp`` runs all available commands in sequence
3. ``npm link`` create a link to current project
4. In your web project ``npm link @gk-software/app-enablement-adapter`` to use your current development version of npm package

Available gulp tasks:
- ``gulp clean`` will remove dist folder
- ``gulp doc`` wil generate documentation in dist/doc folder (configuration in jsdocConfig.json)
- ``gulp copyJs`` will copy sources to dist/full folder

## Test
Not available yet

## Publish new snapshot/release
[See](../../README.md)

## Use as npm dependency
``npm install @gk-software/app-enablement-adapter``
 or
``yarn install @gk-software/app-enablement-adapter``
 adds a dependency to your project.
 
## Code example

NOTE: this example should run as client in host app (like FullPOS, MobilePOS or any other host system which has implemented app enablement API).

Create index html and add appEnablement resources as scripts.
For example use sources from npm package in ``node_modeules/gk-software/app-enablement-adapter/dist/full``.
Use any build support systems like ``gulp`` or ``grunt`` to copy the app enablement sources to dedicated folder.

index.html
```html
<!DOCTYPE html>
<html dir="ltr" lang="de-DE">
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>

    <script type="text/javascript" src="./libs/appEnablement/AppEnablementConnector.js"></script>
    <script type="text/javascript" src="./libs/appEnablement/api/Common.js"></script>
    <script type="text/javascript" src="./libs/appEnablement/api/Masterdata.js"></script>
    <script type="text/javascript" src="./libs/appEnablement/api/Pos.js"></script>

    <script type="text/javascript" src="index.js"></script>
</head>
<body></body>
</html>
```

Create index.js file where we add code to communicate with host system.

index.js
```javascript
var oAppEnablementCommonInstance = new comGkSoftwareGkrAppEnablementApi.Common();
var oAppEnablementMasterdataInstance = new comGkSoftwareGkrAppEnablementApi.Masterdata();
var oAppEnablementPosInstance = new comGkSoftwareGkrAppEnablementApi.Pos();

// get current POS session
function getSessionContext() {
  oAppEnablementCommonInstance.getSessionContext('currentSessionContextFound', 'noCurrentSessionContext');
}

// callback when get POS session
function currentSessionContextFound(context) {
  this.context = context;
  console.log('SUCCESS resultOfGetSessionContext', context);
}

// callback when get POS session fails
function noCurrentSessionContext(error) {
  console.log('ERROR resultOfGetSessionContext', error);
}

// load item data from master data
function getItemDataByID() {
  oAppEnablementMasterdataInstance.getItemDataByID('getItemDataByIDFound', 'getItemDataByIDNotFound', oAppEnablementMasterdataInstance.createGetItemDataByIDRequest("10003"));
}

// callback when item data is retrieved
function getItemDataByIDFound(item) {
  console.log('SUCCESS resultOfGetItemDataByID', item);
}

// callback when item data is not retrieved
function getItemDataByIDNotFound(error) {
  console.log('ERROR resultOfGetItemDataByID', error);
}

// load current open transaction from host POS
function getCurrentTransaction() {
  oAppEnablementPosInstance.getCurrentTransaction('transactionFound', 'noTransaction');
}

// callback when transaction is retrieved
function transactionFound(tx) {
  console.log('SUCCESS resultOfGetCurrentTransaction', tx);
}

// callback when transaction is not retrieved
function noTransaction(error) {
  console.log('ERROR resultOfGetCurrentTransaction', error);
}

getSessionContext();
getItemDataByID();
getCurrentTransaction();
```

In browser console you will see an output
```
index.js:11 SUCCESS resultOfGetSessionContext {businessUnitGroupID: "1", businessUnitID: "9090", isoCurrencyCode: "EUR", storeLanguage: "en_US", tenantID: "003", …}
index.js:23 SUCCESS resultOfGetItemDataByID {key: {…}, name: "Apples", description: "", taxGroupID: "A0", taxExemptCode: "NORMAL", …}
index.js:35 SUCCESS resultOfGetCurrentTransaction {key: {…}, operatorID: "1", workstationID: "101", businessUnitID: "9090", businessDayDate: "2020-04-24T00:00:00.000", …}
```
